Module: ObjectiveElements

Defined in:
lib/objective_elements.rb,
lib/objective_elements/version.rb

Overview

Author: Robert Buchberger robert@buchberger.cc

This module provides a few helpful classes for generating HTML using simple Ruby. Its goal is to be lightweight, and more focused than the general-purpose nature of nokogiri.

Constant Summary collapse

VERSION =
'2.0.0'